@@ -1,6 +1,5 @@
 package Lemonldap::NG::Portal::SharedConf::DBI;
 
-use 5.006;
 use strict;
 use warnings;
 
@@ -25,10 +24,7 @@ sub getConf {
     our $cfgNum = 0;
     $self->{dbiTable} ||= "lmConfig";
     die "No DBI chain found" unless ( $self->{dbiChain} );
-    $dbh = DBI->connect_cached(
-        $self->{dbiChain}, $self->{dbiUser},
-        $self->{dbiPassword}, { RaiseError => 1 }
-    );
+    $dbh = DBI->connect_cached( $self->{dbiChain}, $self->{dbiUser}, $self->{dbiPassword}, { RaiseError => 1 } );
     my $sth = $dbh->prepare("SELECT max(cfgNum) from lmConfig");
     $sth->execute();
     my $row = $sth->fetchrow_arrayref or return 0;
@@ -36,8 +32,7 @@ sub getConf {
     if ( $cfgNum != $row->[0] ) {
         $cfgNum = $row->[0];
         my $sth =
-          $dbh->prepare(
-                "select groupRules, globalStorage, globalStorageOptions, "
+          $dbh->prepare( "select groups, globalStorage, globalStorageOptions, "
               . "exportedVars, domain, ldapServer, ldapPort, securedCookie, "
               . "cookieName, authentication from "
               . $self->{dbiTable}
@@ -92,7 +87,8 @@ compatible portals using a central configuration database using L<DBI>.
     print '<input type="hidden" name="url" value="'.$portal->param('url').'">';
     # Next, login and password
     print 'Login : <input name="user"><br>';
-    print 'Password : <input name="pasword" type="password" autocomplete="off">';
+    print 'Password : <input name="password" type="password" autocomplete="off">';
+    print '<input type=submit value="OK">';
     print '</form>';
   }
 
